==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-taskbar/translations/taskbar_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>RazorTaskButton</name>
    <message>
        <location filename="../razortaskbutton.cpp" line="371"/>
        <source>Application</source>
        <translation>Applicazione</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="404"/>
        <source>To &amp;Desktop</source>
        <translation>Al &amp;Desktop</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="406"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Tutti i Desktops</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="413"/>
        <source>Desktop &amp;%1</source>
        <translation>Desktop &amp;%1</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="420"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Al desktop corrente</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="429"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ssimizza</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="438"/>
        <source>Maximize vertically</source>
        <translation>Massimizza verticalmente</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="443"/>
        <source>Maximize horizontally</source>
        <translation>Massimizza Orizzontalmente</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="449"/>
        <source>&amp;Restore</source>
        <translation>&amp;Ripristina</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="453"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimizza</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="459"/>
        <source>Roll down</source>
        <translation>Minimizza</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="465"/>
        <source>Roll up</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="474"/>
        <source>&amp;Layer</source>
        <translation>&amp;Strato</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="476"/>
        <source>Always on &amp;top</source>
        <translation>Sempre in &amp;alto</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="481"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normale</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="486"/>
        <source>Always on &amp;bottom</source>
        <translation>Sempre in &amp;basso</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="494"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="14"/>
        <source>Razor Task Manager Settings</source>
        <translation>Impostazioni del Task Manager Razor</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="20"/>
        <source>Window List Content</source>
        <translation>Mostra finestre</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="26"/>
        <source>Show windows from current desktop</source>
        <translation>Mostra finestre sul dektop corrente</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="29"/>
        <location filename="../razortaskbarconfiguration.ui" line="39"/>
        <source>wlcB</source>
        <translation>wlcB</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="36"/>
        <source>Show windows from all desktops</source>
        <translation>Mostra finestre da tutti i desktops</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="49"/>
        <source>Window List Appearance</source>
        <translation>Aspetto delle finestre</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="55"/>
        <source>Button style</source>
        <translation>Stile dei pulsanti</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="65"/>
        <source>Max button width</source>
        <translation>Massima Larghezza pulsanti</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="43"/>
        <source>Icon and text</source>
        <translation>Icone e testo</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="44"/>
        <source>Only icon</source>
        <translation>Solo icone</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="45"/>
        <source>Only text</source>
        <translation>Solo testo</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-taskbar/translations/taskbar_it_IT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>RazorTaskButton</name>
    <message>
        <source>Application</source>
        <translation>Applicazione</translation>
    </message>
    <message>
        <source>To &amp;Desktop</source>
        <translation>Al &amp;desktop</translation>
    </message>
    <message>
        <source>&amp;All Desktops</source>
        <translation>&amp;Tutti i desktop</translation>
    </message>
    <message>
        <source>Desktop &amp;%1</source>
        <translation>Desktop &amp;%1</translation>
    </message>
    <message>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Al desktop corrente</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ssimizza</translation>
    </message>
    <message>
        <source>Maximize vertically</source>
        <translation>Massimizza verticalmente</translation>
    </message>
    <message>
        <source>Maximize horizontally</source>
        <translation>Massimizza orizzontalmente</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Ripristina</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimizza</translation>
    </message>
    <message>
        <source>Roll down</source>
        <translation>Srotola</translation>
    </message>
    <message>
        <source>Roll up</source>
        <translation>Arrotola</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation>&amp;Livello</translation>
    </message>
    <message>
        <source>Always on &amp;top</source>
        <translation>Sempre in &amp;alto</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normale</translation>
    </message>
    <message>
        <source>Always on &amp;bottom</source>
        <translation>Sempre in &amp;basso</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <source>Razor Task Manager Settings</source>
        <translation>Impostazioni del Gestore dei processi di Razor</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation>Contenuto dell&apos;elenco delle finestre</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation>Mostra finestre sul desktop corrente</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation>Mostra finestre da tutti i desktop</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation>Aspetto dell&apos;elenco delle finestre</translation>
    </message>
    <message>
        <source>Button style</source>
        <translation>Stile dei pulsanti</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation>Larghezza massima dei pulsanti</translation>
    </message>
    <message>
        <source>Close on middle-click</source>
        <translation>Chiudi con un clic del tasto centrale</translation>
    </message>
    <message>
        <source>Icon and text</source>
        <translation>Icone e testo</translation>
    </message>
    <message>
        <source>Only icon</source>
        <translation>Solo icone</translation>
    </message>
    <message>
        <source>Only text</source>
        <translation>Solo testo</translation>
    </message>
</context>
</TS>
